getFixest_ssc: Gets the default values for the small sample correction

View source: R/VCOV.R

getFixest_sscR Documentation

Gets the default values for the small sample correction

Description

Gets the default small sample correction, of class ssc_type, for specific fixest VCOVs

Usage

getFixest_ssc(vcov_name = NULL)

Arguments

vcov_name

A character scalar naming the type of VCOV, or NULL. It should give the name of a valid fixest VCOV (see vcov.fixest). If so, an object of class ssc_type is returned. If NULL, the list of all small sample corrections (of class ssc_type) which have been set by the user is returned.

Value

If vcov_name is a valid fixest VCOV name, an object of class ssc_type is returned, it corresponds to the default small sample correction (SSC) for this VCOV.

If NULL, all the SSCs that have been set by the user with setFixest_ssc are returned.

See Also

vcov.fixest, ssc, setFixest_ssc

Examples


# default SSC for iid
getFixest_ssc("iid")

# in a fresh session, the default for Newey West VCOVs is different:
getFixest_ssc("NW")


fixest documentation built on March 18, 2026, 9:06 a.m.