This function extracts the log-likelihood from a fixest estimation.
Usage
# S3 method for class 'fixest'
logLik(object, ...)Value
It returns an object of class logLik.
Details
This function extracts the log-likelihood based on the model fit. You can have more
information on the likelihoods in the details of the function femlm.
See also
See also the main estimation functions femlm, feols or feglm. Other
statistics functions: AIC.fixest, BIC.fixest.