print.fixest_multi: Print method for fixest_multi objects

View source: R/fixest_multi.R

print.fixest_multiR Documentation

Print method for fixest_multi objects

Description

Displays summary information on fixest_multi objects in the R console.

Usage

## S3 method for class 'fixest_multi'
print(x, type = "etable", ...)

Arguments

x

A fixest_multi object, obtained from a fixest estimation leading to multiple results.

type

A character either equal to "etable", "short", "long", "compact", "se_compact" or "se_long". If etable, the function etable is used to print the result. If short, only the table of coefficients is displayed for each estimation. If long, then the full results are displayed for each estimation. If compact, a data.frame is returned with one line per model and the formatted coefficients + standard-errors in the columns. If se_compact, a data.frame is returned with one line per model, one numeric column for each coefficient and one numeric column for each standard-error. If "se_long", same as "se_compact" but the data is in a long format instead of wide.

...

Other arguments to be passed to summary.fixest_multi.

See Also

The main fixest estimation functions: feols, fepois, fenegbin, feglm, feNmlm. Tools for mutliple fixest estimations: summary.fixest_multi, print.fixest_multi, as.list.fixest_multi, sub-sub-.fixest_multi, sub-.fixest_multi.

Examples


base = iris
names(base) = c("y", "x1", "x2", "x3", "species")

# Multiple estimation
res = feols(y ~ csw(x1, x2, x3), base, split = ~species)

# Let's print all that
res


fixest documentation built on March 18, 2026, 9:06 a.m.