setFixest_ssc: Sets the default values for the small sample correction

View source: R/VCOV.R

setFixest_sscR Documentation

Sets the default values for the small sample correction

Description

Sets the default values for the Small Sample Correction (SSC) for specific fixest VCOVs

Usage

setFixest_ssc(ssc_type = NULL, vcov_names = "iid")

Arguments

ssc_type

Either NULL (default), or an object of class ssc_type obtained with the function ssc, or old options values (of class setFixest_ssc). By default, if NULL, it resets the SSC to their default value for the selected VCOVs. Otherwise it sets the default SSC for the selected VCOVs to the value returned by the function ssc().

vcov_names

Character vector corresponding to the keywords of the VCOVs for which to change the default SSC. By default it is equal to "iid". Some common VCOV names are: "iid", "hetero", "cluster", "twoway", "newey", "driscoll", "conley".

Value

This functions invisibly returns the list of old settings, a list of class setFixest_ssc.

See Also

vcov.fixest, ssc, getFixest_ssc

Examples


# Estimation with current default values for the small sample correction
feols(Sepal.Length ~ Petal.Length + Petal.Width, iris)

# looking at the default SSC
getFixest_ssc("iid")

# 1) setting new default (and saving the previous opts)
old_opts = setFixest_ssc(ssc(K.adj = FALSE), "iid")
# => the SEs/t-stat differ
feols(Sepal.Length ~ Petal.Length + Petal.Width, iris)

getFixest_ssc("iid")

# 2) resetting to the old values
setFixest_ssc(old_opts)
getFixest_ssc("iid")



fixest documentation built on March 18, 2026, 9:06 a.m.