- object
A fixest object. For example an estimation obtained from feols.
- vcov
Versatile argument to specify the VCOV.
In general, it is either a character scalar equal to a VCOV type, either a formula of the form:
vcov_type ~ variables. The VCOV types implemented are: "iid", "hetero" (or "HC1"),
"cluster", "twoway", "NW" (or "newey_west"), "DK" (or "driscoll_kraay"), and "conley".
It also accepts object from vcov_cluster, vcov_NW, NW, vcov_DK, DK, vcov_conley and conley.
It also accepts covariance matrices computed externally.
Finally it accepts functions to compute the covariances.
See the vcov documentation in the vignette.
You can pass several VCOVs (as above) if you nest them into a list.
If the number of VCOVs equals the number of models, each VCOV is mapped to the appropriate model.
If there is one model and several VCOVs, or if the first element of the list is equal to
"each" or "times", then the estimations will be replicated and the results
for each estimation and each VCOV will be reported.
- ssc
An object of class ssc_type obtained with the function ssc. Represents
how the small sample correction should be done. You must use the function ssc
for this argument. The arguments and defaults of the function ssc are:
K.adj = TRUE, K.fixef = "nonnested", G.adj = TRUE, G.df = "min",
t.df = "min", K.exact = FALSE). See the help of the function ssc for details.
Not all VCOV types are affected by this argument.
- cluster
Tells how to cluster the standard-errors (if clustering is requested). Can
be either a list of vectors, a character vector of variable names, a formula or an
integer vector. Assume we want to perform 2-way clustering over var1 and var2 contained
in the data.frame base used for the estimation. All the following cluster arguments
are valid and do the same thing: cluster = base[, c("var1, "var2")],
cluster = c("var1, "var2"), cluster = ~var1+var2. If the two variables were used as
clusters in the estimation, you could further use cluster = 1:2 or leave it blank
with se = "twoway" (assuming var1 [resp. var2] was the 1st [resp. 2nd] cluster).
- keep
Character vector. This element is used to display only a subset of variables. This
should be a vector of regular expressions (see base::regex help for more info). Each
variable satisfying any of the regular expressions will be kept. This argument is applied post
aliasing (see argument dict).
Use the argument keep_raw for the same effect before aliasing.
Example: you have the variable x1 to x55 and want to display
only x1 to x9, then you could use keep = "x[[:digit:]]$". If the first character is an
exclamation mark, the effect is reversed (e.g. keep = "!Constant" means: every variable that
does not contain “Constant” is kept). See details.
- drop
Character vector. This element is used if some variables are not to be displayed.
This should be a vector of regular expressions (see base::regex help for more info). Each
variable satisfying any of the regular expressions will be discarded. This argument is applied
post aliasing (see argument dict).
Use the argument drop_raw for the same effect before aliasing.
Example: you have the variable x1 to x55 and want to
display only x1 to x9, then you could use drop = "x[[:digit:]]{2}". If the first character
is an exclamation mark, the effect is reversed (e.g. drop = "!Constant" means: every variable
that does not contain “Constant” is dropped). See details.
- order
Character vector. This element is used if the user wants the variables to be
ordered in a certain way. This should be a vector of regular expressions (see base::regex
help for more info). The variables satisfying the first regular expression will be placed first,
then the order follows the sequence of regular expressions. This argument is applied post
aliasing (see argument dict). Use the argument order_raw for the same effect before aliasing.
Example: you have the following variables: month1 to month6,
then x1 to x5, then year1 to year6. If you want to display first the x's, then the
years, then the months you could use: order = c("x", "year"). If the first character is an
exclamation mark, the effect is reversed (e.g. order = "!Constant" means: every variable that
does not contain “Constant” goes first). See details.
- list
Logical, default is FALSE. If TRUE, then a nested list is returned, the
first layer is accessed with the coefficients names; the second layer with the
following values: coef, se, tstat, pvalue. Note that the variable "(Intercept)"
is renamed into "constant".
- ...
Other arguments to be passed to summary.fixest.