| coeftable.fixest_multi | R Documentation |
fixest_multi estimationsSeries of methods to extract the coefficients table or its sub-components from a
fixest_multi objects (i.e. the outcome of multiple estimations).
## S3 method for class 'fixest_multi'
coeftable(
object,
vcov = NULL,
keep = NULL,
drop = NULL,
order = NULL,
long = FALSE,
wide = FALSE,
...
)
## S3 method for class 'fixest_multi'
se(
object,
vcov = NULL,
keep = NULL,
drop = NULL,
order = NULL,
long = FALSE,
...
)
## S3 method for class 'fixest_multi'
tstat(
object,
vcov = NULL,
keep = NULL,
drop = NULL,
order = NULL,
long = FALSE,
...
)
## S3 method for class 'fixest_multi'
pvalue(
object,
vcov = NULL,
keep = NULL,
drop = NULL,
order = NULL,
long = FALSE,
...
)
object |
A |
vcov |
Versatile argument to specify the VCOV.
In general, it is either a character scalar equal to a VCOV type, either a formula of the form:
vcov_type ~ variables. The VCOV types implemented are: "iid", "hetero" (or "HC1"),
"cluster", "twoway", "NW" (or "newey_west"), "DK" (or "driscoll_kraay"), and "conley".
It also accepts object from vcov_cluster, vcov_NW, NW, vcov_DK, DK, vcov_conley and conley.
It also accepts covariance matrices computed externally.
Finally it accepts functions to compute the covariances.
See the vcov documentation in the vignette.
You can pass several VCOVs (as above) if you nest them into a list.
If the number of VCOVs equals the number of models, eahc VCOV is mapped to the appropriate model.
If there is one model and several VCOVs, or if the first element of the list is equal to
|
keep |
Character vector. This element is used to display only a subset of variables. This
should be a vector of regular expressions (see Example: you have the variable |
drop |
Character vector. This element is used if some variables are not to be displayed.
This should be a vector of regular expressions (see Example: you have the variable |
order |
Character vector. This element is used if the user wants the variables to be
ordered in a certain way. This should be a vector of regular expressions (see Example: you have the following variables: |
long |
Logical scalar, default is |
wide |
A logical scalar, default is |
... |
Other arguments to be passed to |
It returns a data.frame containing the coefficients tables (or just the se/pvalue/tstat)
along with the information on which model was estimated.
If wide = TRUE, then a list is returned. The elements of the list are
coef/se/tstat/pvalue. Each element of the list is a wide table with a column per coefficient.
If long = TRUE, then all the information is stacked. This removes the 4 columns
containing the coefficient estimates to the p-values, and replace them with two
new columns: "param" and "value". The column param contains the
values coef/se/tstat/pvalue, and the column values the
associated numerical information.
se(fixest_multi): Extracts the standard-errors from fixest_multi estimations
tstat(fixest_multi): Extracts the t-stats from fixest_multi estimations
pvalue(fixest_multi): Extracts the p-values from fixest_multi estimations
base = setNames(iris, c("y", "x1", "x2", "x3", "species"))
est_multi = feols(y ~ csw(x.[,1:3]), base, split = ~species)
# we get all the coefficient tables at once
coeftable(est_multi)
# Now just the standard-errors
se(est_multi)
# wide = TRUE => leads toa list of wide tables
coeftable(est_multi, wide = TRUE)
# long = TRUE, all the information is stacked
coeftable(est_multi, long = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.