| getFixest_ssc | R Documentation |
Gets the default small sample correction, of class ssc_type, for specific fixest VCOVs
getFixest_ssc(vcov_name = NULL)
vcov_name |
A character scalar naming the type of VCOV, or |
If vcov_name is a valid fixest VCOV name, an object of class ssc_type is returned,
it corresponds to the default small sample correction (SSC) for this VCOV.
If NULL, all the SSCs that have been set by the user with setFixest_ssc are returned.
vcov.fixest, ssc, setFixest_ssc
# default SSC for iid
getFixest_ssc("iid")
# in a fresh session, the default for Newey West VCOVs is different:
getFixest_ssc("NW")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.