logLik.fixest: Extracts the log-likelihood

View source: R/methods.R

logLik.fixestR Documentation

Extracts the log-likelihood

Description

This function extracts the log-likelihood from a fixest estimation.

Usage

## S3 method for class 'fixest'
logLik(object, ...)

Arguments

object

A fixest object. Obtained using the functions femlm, feols or feglm.

...

Not currently used.

Details

This function extracts the log-likelihood based on the model fit. You can have more information on the likelihoods in the details of the function femlm.

Value

It returns an object of class logLik.

Author(s)

Laurent Berge

See Also

See also the main estimation functions femlm, feols or feglm. Other statistics functions: AIC.fixest, BIC.fixest.

Examples


# simple estimation on iris data with "Species" fixed-effects
res = femlm(Sepal.Length ~ Sepal.Width + Petal.Length +
            Petal.Width | Species, iris)

nobs(res)
logLik(res)



fixest documentation built on March 18, 2026, 9:06 a.m.