| logLik.fixest | R Documentation |
This function extracts the log-likelihood from a fixest estimation.
## S3 method for class 'fixest'
logLik(object, ...)
object |
A |
... |
Not currently used. |
This function extracts the log-likelihood based on the model fit. You can have more
information on the likelihoods in the details of the function femlm.
It returns an object of class logLik.
Laurent Berge
See also the main estimation functions femlm, feols or feglm. Other
statistics functions: AIC.fixest, BIC.fixest.
# simple estimation on iris data with "Species" fixed-effects
res = femlm(Sepal.Length ~ Sepal.Width + Petal.Length +
Petal.Width | Species, iris)
nobs(res)
logLik(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.