print.ssc_type: Method to print the type of small sample correction

View source: R/VCOV.R

print.ssc_typeR Documentation

Method to print the type of small sample correction

Description

Pretty print for the small sample correction obtained from ssc

Usage

## S3 method for class 'ssc_type'
print(x, ...)

Arguments

x

An object of class ssc_type, obtained from the function ssc.

...

Not currently used.

Value

This function does not return anything.

See Also

vcov.fixest, ssc, setFixest_ssc, getFixest_ssc

Examples


# ssc() is just a list
unclass(ssc())

# print of ssc, much more compactly
ssc()


fixest documentation built on March 18, 2026, 9:06 a.m.