| setFixest_ssc | R Documentation |
Sets the default values for the Small Sample Correction (SSC) for specific fixest VCOVs
setFixest_ssc(ssc_type = NULL, vcov_names = "iid")
ssc_type |
Either |
vcov_names |
Character vector corresponding to the keywords of the VCOVs for which
to change the default SSC. By default it is equal to |
This functions invisibly returns the list of old settings, a list of class setFixest_ssc.
vcov.fixest, ssc, getFixest_ssc
# Estimation with current default values for the small sample correction
feols(Sepal.Length ~ Petal.Length + Petal.Width, iris)
# looking at the default SSC
getFixest_ssc("iid")
# 1) setting new default (and saving the previous opts)
old_opts = setFixest_ssc(ssc(K.adj = FALSE), "iid")
# => the SEs/t-stat differ
feols(Sepal.Length ~ Petal.Length + Petal.Width, iris)
getFixest_ssc("iid")
# 2) resetting to the old values
setFixest_ssc(old_opts)
getFixest_ssc("iid")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.